
History
=======

1.1.2
-----

- CSS fix.
  [rnix, 2012-10-30]

1.1.1
-----

- use ``yafowil.utils.attr_value`` wherever possible.
  [rnix, 2012-10-25]

1.1
---

- Adopt resource providing
  [rnix, 2012-06-12]

- Provide example widget
  [rnix, 2012-06-12]

1.0.1
-----

- Add ``nocache`` request parameter to image ``src`` on edit.
  [rnix, 2012-31-05]

- JS Fix.
  [rnix, 2012-31-05]

1.0
---

- Make it work
  [rnix]
